@@ -578,3 +578,171 @@ test_that("BiSSE_fHiSSE_test2", {
     comparison <- identical(round(hisse.full,4), round(diversitree.full,4))
     expect_true(comparison)
 })
+
+
+test_that("HiSSE_Null_Four_fHiSSE_test", {
+    skip_on_cran()
+    
+    library(diversitree)
+    pars <- c(0.1, 0.1, 0.03, 0.03, 0.01, 0.01)
+    set.seed(4)
+    phy <- NULL
+    while( is.null( phy ) ){
+        phy <- tree.bisse(pars, max.t=30, x0=0)
+    }
+    lik <- make.bisse(phy, phy$tip.state)
+    diversitree.full <- lik(pars)
+    
+    states <- data.frame(phy$tip.state, phy$tip.state, row.names=names(phy$tip.state))
+    states <- states[phy$tip.label,]
+    pars.hisse.null <- c(0.1+0.03, 0.2+0.03, 0.1+0.05, 0.2+0.05, 0.1+0.03, 0.2+0.03, 0.1+0.05, 0.2+0.05, 0.03/.1, 0.03/.2, 0.05/.1, 0.05/.2, 0.03/.1, 0.03/.2, 0.05/.1, 0.05/.2, rep(0.01, 32))
+    model.vec = pars.hisse.null
+    phy$node.label = NULL
+    cache <- hisse:::ParametersToPassNull(phy, states[,1], model.vec, f=c(1,1))
+    hisse.nullOG.full <- hisse:::DownPassNull(phy, cache, root.type="madfitz", condition.on.survival=TRUE, root.p=NULL)
+    
+    hidden.states=TRUE
+    states <- data.frame(phy$tip.state, phy$tip.state, row.names=names(phy$tip.state))
+    states <- states[phy$tip.label,]
+    gen <- hisse:::FindGenerations(phy)
+    dat.tab <- hisse:::OrganizeDataHiSSE(states, phy=phy, f=c(1,1), hidden.states=hidden.states)
+    pars.hisse <- c(0.1+0.03, 0.1+0.03, 0.03/0.1, 0.03/0.1, 0.01, 0.01, 0.01, rep(0.01,5), 0.2+0.03, 0.2+0.03, 0.03/.2, 0.03/.2, 0.01, 0.01, 0.01, rep(0.01,5), 0.1+0.05, 0.1+0.05, 0.05/.1, 0.05/.1, 0.01, 0.01, 0.01, rep(0.01,5), 0.2+0.05, 0.2+0.05, 0.05/.2, 0.05/.2, 0.01, 0.01, 0.01, rep(0.01,5))
+    model.vec <- numeric(48)
+    model.vec[1:48] = pars.hisse
+    phy$node.label = NULL
+    cache = hisse:::ParametersToPassfHiSSE(model.vec, hidden.states=hidden.states, nb.tip=Ntip(phy), nb.node=Nnode(phy),  bad.likelihood=-300, ode.eps=0)
+    hisse.null.full <- hisse:::DownPassHiSSE(dat.tab, gen, cache, root.type="madfitz", condition.on.survival=TRUE, root.p=NULL)
+    comparison <- identical(round(hisse.nullOG.full,4), round(hisse.null.full,4))
+    
+    expect_true(comparison)
+})
+
+
+test_that("GeoSSE_fGeoSSSE_test1", {
+    skip_on_cran()
+
+    library(diversitree)
+    pars <- c(1.5, 0.5, 1.0, 0.7, 0.4, 2.5, 0.5)
+    names(pars) <- diversitree:::default.argnames.geosse()
+    set.seed(9)
+    phy <- tree.geosse(pars, max.t=4, x0=0)
+    lik <- make.geosse(phy, phy$tip.state, sampling.f=c(.2,.2,.2))
+    diversitree.full <- lik(pars)
+    
+    states <- data.frame(phy$tip.state, phy$tip.state, row.names=names(phy$tip.state))
+    states <- states[phy$tip.label,]
+    names(pars) <- NULL
+    model.vec <- numeric(380)
+    model.vec[1:11] <- c(1.5+0.7, 0.5+0.4, sum(1.5, 0.5, 1.0), pars[4]/pars[1], pars[5]/pars[2], 0, pars[6], 0, pars[7], 0,0)
+    phy$node.label <- NULL
+    cache.slim <- hisse:::ParametersToPassGeoHiSSEfast(model.vec=model.vec, hidden.states=FALSE,nb.tip=Ntip(phy), nb.node=Nnode(phy), bad.likelihood=exp(-500), ode.eps=0)
+    gen <- hisse:::FindGenerations(phy)
+    dat.tab <- hisse:::OrganizeDataGeo(states[,1], phy, c(.2,.2,.2), hidden.states=FALSE)
+    geohisse.new <- hisse:::DownPassGeoHissefast(dat.tab, gen=gen, cache=cache.slim, root.type="madfitz", condition.on.survival=TRUE, root.p=NULL)
+    
+    model.vec[1:11] <- c(1.5, 0.5, 1.0, pars[4], pars[5], 0, pars[6], 0, pars[7], pars[5], pars[4])
+    cache <- hisse:::ParametersToPassGeoHiSSE(phy, states[,1], f=c(.2,.2,.2), model.vec, hidden.states=FALSE)
+    geohisse.full <- hisse:::DownPassGeoHisse(phy=phy, cache=cache, hidden.states=TRUE, bad.likelihood=-1000000, condition.on.survival=TRUE, root.type="madfitz", root.p=NULL)
+    comparison <- identical(round(geohisse.full,4), round(diversitree.full,4), round(geohisse.new,4))
+    
+    expect_true(comparison)
+})
+
+
+test_that("GeoSSE_fGeoSSSE_test2", {
+    skip_on_cran()
+    
+    library(diversitree)
+    pars <- c(1.5, 0.5, 1.0, 0.7, 0.4, 2.5, 0.5)
+    names(pars) <- diversitree:::default.argnames.geosse()
+    set.seed(9)
+    phy <- tree.geosse(pars, max.t=4, x0=0)
+    lik <- make.geosse(phy, phy$tip.state)
+    diversitree.full <- lik(pars)
+    
+    states <- data.frame(phy$tip.state, phy$tip.state, row.names=names(phy$tip.state))
+    states <- states[phy$tip.label,]
+    names(pars) <- NULL
+    model.vec <- numeric(380)
+    model.vec[1:76] <- c(0.07612170+0.02869795, 0.07612170+0.02869795, 0, 0.02869795/0.07612170, 0.02869795/0.07612170, 0, 0.02727061, 0, 0.03946784, 0.02869795, 0.02869795, 0.01055818, rep(0, 8), 0.01055818, rep(0, 8), 0.01055818, rep(0, 8), 0.18861747+0.02869795, 0.18861747+0.02869795, 0, 0.02869795/0.18861747, 0.02869795/0.18861747, 0, 0.02727061, 0, 0.03946784, 0.02869795, 0.02869795, 0.01055818, rep(0, 8), 0.01055818, rep(0, 8), 0.01055818, rep(0, 8))
+    phy$node.label <- NULL
+    cache.slim <- hisse:::ParametersToPassGeoHiSSEfast(model.vec=model.vec, hidden.states=TRUE, nb.tip=Ntip(phy), nb.node=Nnode(phy), bad.likelihood=exp(-500), ode.eps=0)
+    gen <- hisse:::FindGenerations(phy)
+    dat.tab <- hisse:::OrganizeDataGeo(states[,1], phy, c(1,1,1), hidden.states=TRUE)
+    geohisse.new <- hisse:::DownPassGeoHissefast(dat.tab, gen=gen, cache=cache.slim, root.type="madfitz", root.p=NULL, condition.on.survival=TRUE)
+    
+    model.vec <- c(0.07612170, 0.07612170, 0.07612170, 0.02869795, 0.02869795, 0.00000000, 0.02727061,
+    0.00000000, 0.03946784, 0.00000000, 0.00000000, 0.01055818, 0.00000000, 0.00000000,
+    0.00000000, 0.01055818, 0.00000000, 0.00000000, 0.00000000, 0.01055818, 0.00000000,
+    0.00000000, 0.00000000, 0.18861747, 0.18861747, 0.18861747, 0.02869795, 0.02869795,
+    0.00000000, 0.02727061, 0.00000000, 0.03946784, 0.00000000, 0.00000000, 0.01055818,
+    0.00000000, 0.00000000, 0.00000000, 0.01055818, 0.00000000, 0.00000000, 0.00000000,
+    0.01055818, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000, 0.00000000,
+    0.00000000, 0.00000000, 0.00000000)
+    cache <- hisse:::ParametersToPassGeoHiSSE(phy, states[,1], f=c(1,1,1), model.vec, hidden.states=TRUE)
+    geohisse.full <- hisse:::DownPassGeoHisse(phy=phy, cache=cache, hidden.states=TRUE, bad.likelihood=-1000000, condition.on.survival=TRUE, root.type="madfitz", root.p=NULL)
+    comparison <- identical(round(geohisse.full,4), round(geohisse.new,4))
+    
+    expect_true(comparison)
+})
+
+
+test_that("GeoSSE_fGeoSSSE_test3", {
+
+    library(diversitree)
+    pars <- c(.1,  .15,  .2,  # lambda 1, 2, 3
+    .03, .045, .06, # mu 1, 2, 3
+    .05, 0,         # q12, q13
+    .05, .05,       # q21, q23
+    0,   .05)       # q31, q32
+    set.seed(2)
+    phy <- tree.musse(pars, 30, x0=1)
+    states <- phy$tip.state
+    lik <- make.musse(phy, states, 3)
+    lik.base <- constrain(lik, lambda2 ~ lambda1, lambda3 ~ 0,
+    mu2 ~ mu1, mu3 ~ 0,
+    q13 ~ 0, q21 ~ q12, q23 ~ q12, q31 ~ 0.03, q32 ~ q12)
+    diversitree.constrained = lik.base(c(.1, .03, .05))
+    diversitree.full = lik(pars)
+
+    states <- data.frame(phy$tip.state, phy$tip.state, row.names=names(phy$tip.state))
+    states <- states[phy$tip.label,]
+    states[states[,1]==3,] = 4
+    pars.hisse <- c(0.1, 0.1, 0, 0.03, 0.03, 0.0, 0.05, 0, 0.05, 0.05, 0, 0.05)
+    model.vec = rep(0,120)
+    model.vec[1:12] = pars.hisse
+    phy$node.label = NULL
+    cache <- hisse:::ParametersToPassMuSSE(phy, states[,1], model.vec, f=c(1,1,1), hidden.states="TEST1")
+    hisse.constrained <- hisse:::DownPassMusse(phy, cache, hidden.states=FALSE, root.type="madfitz", condition.on.survival=TRUE, root.p=NULL)
+    #comparison <- identical(round(hisse.constrained,4), round(diversitree.constrained,4))
+
+    states.new <- numeric(Ntip(phy))
+    for(i in 1:Ntip(phy)){
+        if(states[i,1]==1){states.new[i]=1}
+        if(states[i,1]==2){states.new[i]=2}
+        if(states[i,1]==4){states.new[i]=0}
+    }
+
+    states <- cbind(states, states.new)
+    pars.hisse <- c(0.1+0.03, 0.1+0.03, 0, 0.03/0.1, 0.03/0.1, 0.05, 0, 0.05, 0.05, 0, 0.05)
+    model.vec = rep(0,380)
+    model.vec[1:11] = pars.hisse
+    phy$node.label = NULL
+    cache.slim <- hisse:::ParametersToPassGeoHiSSEfast(model.vec=model.vec, hidden.states=FALSE, assume.cladogenetic=FALSE, nb.tip=Ntip(phy), nb.node=Nnode(phy), bad.likelihood=exp(-500), ode.eps=0)
+    gen <- hisse:::FindGenerations(phy)
+    dat.tab <- hisse:::OrganizeDataGeo(states[,3], phy, c(1,1,1), hidden.states=FALSE)
+    geohisse.new <- hisse:::DownPassGeoHissefast(dat.tab, gen=gen, cache=cache.slim, root.type="madfitz", condition.on.survival=TRUE, root.p=NULL)
+    comparison <- identical(round(hisse.constrained,4), round(diversitree.constrained,4), round(geohisse.new,4))
+
+    expect_true(comparison)
+})
+
